--[=[
Recruiter World of Warcraft Add-on
Copyright (c) 2015 by Eric Isakson (eric.david.isakson@gmail.com), All rights reserved

Version r20151126184015

Recruiter is a tool for coordinating recruitment activities accross guildmates.
It is intended to help provide a consistent message in recruiting activities and
prevent spamming community members with invitations. It is also useful
for managing guild membership with tools for removing inactive members and 
banning players so they are not re-invited by a recruiter after being kicked
from the guild.

This add-on uses the Ace3 framework.

type /recruiter to get a list of existing options.

-----
    Who.lua
-----

This searches for leads using the /who interface.


--]=]

local ERROR     = 1;
local WARNING   = 2;
local INFO      = 3;
local INFO2     = 4;


local ADDON_NAME, T = ...;
local RECRUITER_ = T.Recruiter;
local L = RECRUITER_.Localized_Text;

-- Create module
RECRUITER_.Who = RECRUITER_:NewModule("Who");
local Who = RECRUITER_.Who;

-- Up Values
local _G               = _G;
local UnitGUID         = _G.UnitGUID;
local UnitIsUnit       = _G.UnitIsUnit;
local PlaySoundFile    = _G.PlaySoundFile;
local db               = RECRUITER_.db;
local SetHandler       = RECRUITER_.SetHandler;
local GetLeadProfile   = RECRUITER_.GetLeadProfile;
local GetClassHexColor = RECRUITER_.GetClassHexColor;
local Print            = RECRUITER_.Print;

function Who:OnInitialize() -- {{{
    self:Debug(INFO, "OnInitialize called!");
    self.db = db:RegisterNamespace('Who', {
        global = {
            Who = true,

            UpdateLeadsInterval = 10 * 60, -- 10 minutes
        },
    });
end -- }}}

function Who:GetOptions () -- {{{
    return {
        [Who:GetName()] = {
            name = L[Who:GetName()],
            type = 'group',
            get = function (info) return Who.db.global[info[#info]]; end,
            set = function (info, value) SetHandler(self, info, value) end,
            args = {
                Who = {
                    type = 'toggle',
                    name = L["WHO_OPT"],
                    desc = L["WHO_OPT_DESC"],
                    order = 1,
                },
                TargetingOptions = {
                    type = 'group',
                    inline = true,
                    name = L['WHO_OPT_SETTINGS'],
                    hidden = function() return Who.db.global.Who == false end,
                    order = 40,
                    args = {
                        Description = {
                            type = 'description',
                            order = 0,
                            name = L["WHO_OPT_DESCRIPTION"],
                        },
                        UpdateLeadsInterval = {
                            type = "range",
                            name = L["WHO_OPT_UPDATE_LEADS_INTERVAL"],
                            desc = L["WHO_OPT_UPDATE_LEADS_INTERVAL_DESC"],
                            min = 60,
                            max = 10 * 60, -- 10 minutes
                            step = 15,
                            bigStep = 60,
                            order = 600,
                        },
                    },
                },
            },
        },
    };
end -- }}}


function Who:OnEnable() -- {{{
    self:Debug(INFO, "OnEnable");


    -- TODO self:ScheduleRepeatingTimer(self.UpdateLeads, self.db.global.UpdateLeadsInterval, self);


-- listen to appropriate events
--    self:RegisterEvent("UPDATE_MOUSEOVER_UNIT", "TestUnit");
--    self:RegisterEvent("PLAYER_TARGET_CHANGED", "TestUnit");
end -- }}}

function Who:OnDisable() -- {{{
    self:Debug(INFO2, "OnDisable");
    
--    self:UnregisterEvent("UPDATE_MOUSEOVER_UNIT");
--    self:UnregisterEvent("PLAYER_TARGET_CHANGED");
end -- }}}


